<?php

/**
 * @file
 * Provides Memsource translation plugin controller.
 */

/**
 * Memsource translator UI.
 */
class TMGMTMemsourceTranslatorUIController extends TMGMTDefaultTranslatorUIController {

  /**
   * Overrides TMGMTDefaultTranslatorUIController::pluginSettingsForm().
   */
  public function pluginSettingsForm($form, &$form_state, TMGMTTranslator $translator, $busy = FALSE) {
    $form['service_url'] = array(
      '#type' => 'textfield',
      '#title' => t('Memsource Home URL'),
      '#default_value' => $translator->getSetting('service_url') ?: 'https://cloud.memsource.com/web',
      '#description' => t('Please enter the Memsource Home URL.'),
      '#required' => TRUE,
      '#placeholder' => 'https://cloud.memsource.com/web',
    );
    $form['memsource_user_name'] = [
      '#type' => 'textfield',
      '#title' => t('User name'),
      '#default_value' => $translator->getSetting('memsource_user_name'),
      '#description' => t('Please enter your Memsource Cloud user name.'),
      '#required' => TRUE,
      '#placeholder' => t('Please enter your Memsource Cloud user name.'),
    ];
    $form['memsource_password'] = [
      '#type' => 'password',
      '#title' => t('Password'),
      '#default_value' => $translator->getSetting('memsource_password'),
      '#description' => t('Please enter your Memsource Cloud password.'),
      '#required' => TRUE,
      '#placeholder' => t('Please enter your Memsource Cloud password.'),
    ];
    return parent::pluginSettingsForm($form, $form_state, $translator, $busy);
  }

  /**
   * Implements TMGMTTranslatorUIControllerInterface::checkoutInfo().
   */
  public function checkoutInfo(TMGMTJob $job) {
    $form = array();

    if ($job->isActive()) {
      $form['actions']['pull'] = array(
        '#type' => 'submit',
        '#value' => t('Pull translations'),
        '#submit' => array('_tmgmt_memsource_pull_submit'),
        '#weight' => -10,
      );
    }

    return $form;
  }

  /**
   * Overrides TMGMTDefaultTranslatorUIController::checkoutSettingsForm().
   */
  public function checkoutSettingsForm($form, &$form_state, TMGMTJob $job) {
    /* @var TMGMTMemsourcePluginController $controller The translator object. */
    $controller = $job->getTranslator()->getController();
    /* @var MemsourceConnector $connector The Memsource Connector. */
    $connector = $controller->getConnector($job->getTranslator());

    $project_templates = [];
    for ($page = 0; !isset($templates_page) || !empty($templates_page['content']); $page++) {
      $templates_page = $connector->sendApiRequest('/api2/v1/projectTemplates', 'GET', ['pageNumber' => $page]);
      $project_templates = array_merge($project_templates, $templates_page['content']);
    }

    // Get langs from select fields.
    $sourceLang = $connector->getMappedLanguage($job->source_language);
    $targetLang = $connector->getMappedLanguage($job->target_language);

    $templates = ['0' => '-'];

    foreach ($project_templates as $template) {
      // Display only templates which match the selected source
      // AND (match the selected target lang OR target lang is empty).
      if ($template['sourceLang'] === $sourceLang &&
        (in_array($targetLang, $template['targetLangs'], TRUE) || $template['targetLangs'] === NULL)
      ) {
        $templates[$template['id']] = $template['templateName'];
      }
    }

    $settings['project_template'] = [
      '#type' => 'select',
      '#title' => t('Project template'),
      '#options' => $templates,
      '#description' => t('Select a  Memsource Cloud project template.'),
    ];
    $settings['due_date'] = [
      '#type' => 'date',
      '#title' => t('Due Date'),
      '#date_date_format' => 'Y-m-d',
      '#description' => t('Enter the due date of this translation.'),
      '#default_value' => NULL,
    ];

    return $settings;
  }

}
